==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/Port/src/com/clustercontrol/port/action/DeletePort.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.port.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.port.ejb.session.MonitorPortController;
import com.clustercontrol.port.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * port監視情報を削除するクラスです。
 * 
 * @version 2.4.0
 * @since 2.4.0
 */
public class DeletePort {

    /**
     * port監視情報を削除します。
     * 
     * @param monitorId 監視項目ID
     * @return 削除に成功した場合、true
     */
    public boolean delete(String monitorId) {
    	
    	MonitorPortController port = EjbConnectionManager.getConnectionManager().getPortController();

        boolean result = false;
        try {
        	result = port.deletePort(monitorId);
        	return result;
        	
        } catch (FinderException e) {
        } catch (RemoveException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        } catch (NotSupportedException e) {
        } catch (HeuristicMixedException e) {
        } catch (HeuristicRollbackException e) {
        } catch (RollbackException e) {
        } catch (InvalidTransactionException e) {
        } catch (IllegalStateException e) {
        } catch (SystemException e) {
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return false;
    }
}

==> hinemos_src-3.0.4.tar.gz: Hinemos_src-3.0.4/Port/src/com/clustercontrol/port/action/DeletePort.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.port.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.jms.JMSException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.port.ejb.session.MonitorPortController;
import com.clustercontrol.port.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * port監視情報を削除するクラスです。
 * 
 * @version 3.0.0
 * @since 2.4.0
 */
public class DeletePort {

    /**
     * port監視情報を削除します。
     * 
     * @param monitorId 監視項目ID
     * @return 削除に成功した場合、true
     */
    public boolean delete(String monitorId) {
    	
    	MonitorPortController port = EjbConnectionManager.getConnectionManager().getPortController();

        boolean result = false;
        try {
        	result = port.deletePort(monitorId);
        	return result;
        	
        } catch (FinderException e) {
        } catch (RemoveException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        } catch (NotSupportedException e) {
        } catch (HeuristicMixedException e) {
        } catch (HeuristicRollbackException e) {
        } catch (RollbackException e) {
        } catch (InvalidTransactionException e) {
        } catch (IllegalStateException e) {
        } catch (SystemException e) {
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (CreateException e) {
		
			e.printStackTrace();
		} catch (JMSException e) {
		
			e.printStackTrace();
		}
        return false;
    }
}
